summaryrefslogtreecommitdiffstats
path: root/smb4k/core/smb4kpasswordhandler.h
diff options
context:
space:
mode:
Diffstat (limited to 'smb4k/core/smb4kpasswordhandler.h')
-rw-r--r--smb4k/core/smb4kpasswordhandler.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/smb4k/core/smb4kpasswordhandler.h b/smb4k/core/smb4kpasswordhandler.h
index 744aa15..8898249 100644
--- a/smb4k/core/smb4kpasswordhandler.h
+++ b/smb4k/core/smb4kpasswordhandler.h
@@ -76,12 +76,12 @@ class Smb4KPasswordHandler : public TQObject
* infos in case we need to look up authentication information for
* 'homes' shares.
*
* @param tqparent The tqparent object.
*
* @param name The name this class should carry.
*/
Smb4KPasswordHandler( Smb4KHomesSharesHandler *handler,
- TQObject *tqparent = 0,
+ TQObject *parent = 0,
const char *name = 0 );
#else
/**
@@ -94,13 +94,13 @@ class Smb4KPasswordHandler : public TQObject
* @param o_handler The Smb4KSambaOptionsHandler object. It is needed to write the
* ~/.nsmbrc file correctly.
*
* @param tqparent The tqparent object.
*
* @param name The name this class should carry.
*/
Smb4KPasswordHandler( Smb4KHomesSharesHandler *s_handler,
Smb4KSambaOptionsHandler *o_handler,
- TQObject *tqparent = 0,
+ TQObject *parent = 0,
const char *name = 0 );
#endif
@@ -122,13 +122,13 @@ class Smb4KPasswordHandler : public TQObject
* Values are taken from the Smb4KPasswordHandler::AskPass::Description
* enumeration.
*
* @param tqparent The tqparent of this dialog.
*
* @param name The name of this dialog.
*
* @returns TRUE if a new password has been supplied and FALSE otherwise.
*/
- bool askpass( const TQString &workgroup, const TQString &host, const TQString &share, int desc, TQWidget *tqparent = 0, const char *name = 0 );
+ bool askpass( const TQString &workgroup, const TQString &host, const TQString &share, int desc, TQWidget *parent = 0, const char *name = 0 );
/**
* Returns the authentication data that was found for the defined share. You need to
@@ -76,12 +76,12 @@ class Smb4KPasswordHandler : public TQObject
* 'homes' shares.
*
- * @param tqparent The tqparent object.
+ * @param parent The parent object.
*
* @param name The name this class should carry.
@@ -94,13 +94,13 @@ class Smb4KPasswordHandler : public TQObject
* ~/.nsmbrc file correctly.
*
- * @param tqparent The tqparent object.
+ * @param parent The parent object.
*
* @param name The name this class should carry.
@@ -122,13 +122,13 @@ class Smb4KPasswordHandler : public TQObject
* enumeration.
*
- * @param tqparent The tqparent of this dialog.
+ * @param parent The parent of this dialog.
*
* @param name The name of this dialog.